/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_uKxGOAtF);
  numBytes += sPhasor_k_init(&sPhasor_hKlaHhOo, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_gDU5lh0X);
  numBytes += sRPole_init(&sRPole_lWDkJ9rI);
  numBytes += sRPole_init(&sRPole_cala4zrT);
  numBytes += sTabhead_init(&sTabhead_BsmTXRg6, &hTable_jgmZW2QT);
  numBytes += sTabread_init(&sTabread_6ZF0yv4n, &hTable_jgmZW2QT, false);
  numBytes += sTabread_init(&sTabread_Bx2t6pAh, &hTable_jgmZW2QT, false);
  numBytes += sLine_init(&sLine_cOXAjTOE);
  numBytes += sTabhead_init(&sTabhead_Fy3PzIjv, &hTable_DxHcBV3A);
  numBytes += sTabread_init(&sTabread_oEAgrLHI, &hTable_DxHcBV3A, false);
  numBytes += sTabread_init(&sTabread_YJGbDV5q, &hTable_DxHcBV3A, false);
  numBytes += sLine_init(&sLine_3KtmwMir);
  numBytes += sTabwrite_init(&sTabwrite_s2VzStzY, &hTable_DxHcBV3A);
  numBytes += sTabwrite_init(&sTabwrite_L5lJraop, &hTable_jgmZW2QT);
  numBytes += cVar_init_f(&cVar_OaXHNXaY, 0.0f);
  numBytes += cVar_init_f(&cVar_bwOctKai, 0.0f);
  numBytes += cVar_init_f(&cVar_MqpXQRtx, 0.0f);
  numBytes += cVar_init_f(&cVar_Q01Ehfur, 0.0f);
  numBytes += cVar_init_s(&cVar_2E4VzRYP, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_HW55sIsL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iAmGgJol, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_A4vZiEVn, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_jLHluPGR, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_2SdWrC4r, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_txUTh9pr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SrdXwIA8, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_C68n1UrN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Qno1IsWU, 0.0f);
  numBytes += hTable_init(&hTable_DxHcBV3A, 256);
  numBytes += cDelay_init(this, &cDelay_BNs4tcAQ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_zjot6TCj, 0.0f);
  numBytes += hTable_init(&hTable_jgmZW2QT, 256);
  numBytes += cVar_init_f(&cVar_u29N0OR8, 14.0f);
  numBytes += cBinop_init(&cBinop_Vfo7heMT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_7ykZFzU5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_c3O92MqY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_r0W7JjFz, 14.0f);
  numBytes += cBinop_init(&cBinop_pDmR3hJ9, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HfM7bbem, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WQfHMqKZ, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_uQ5gO8fE, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_CoNdFLTA, 1, -1);
  numBytes += cVar_init_f(&cVar_q0sab865, 0.2f);
  numBytes += cSlice_init(&cSlice_TKsyo9Oz, 1, -1);
  numBytes += cVar_init_f(&cVar_nO6GJWCw, 0.0f);
  numBytes += cSlice_init(&cSlice_2QJuA9Q1, 1, -1);
  numBytes += cVar_init_f(&cVar_fQ7Rkf82, 2.0f);
  numBytes += cSlice_init(&cSlice_YKIfFD3E, 1, -1);
  numBytes += cVar_init_f(&cVar_WBpbeomY, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_DxHcBV3A);
  hTable_free(&hTable_jgmZW2QT);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_DxHcBV3A; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_jgmZW2QT; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iP7R4oiT_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UU9Ii3jo_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3mwyyNmg_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gdVpCjCl_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o97Be0Rd_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FHwzAZ05_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_utcDAiZQ_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5rgCVfVK_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fJULiNYU_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_OaXHNXaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pJVKp9yA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_bwOctKai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vYHG4Y6Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_MqpXQRtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BsgwgDl1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_Q01Ehfur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qEDjJen2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_wxWmDgnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ztAFe2x9_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ztAFe2x9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_hKlaHhOo, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_MbDV0M41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Q08GptsW_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_Q08GptsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fNb3mqrd_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_2E4VzRYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kyuo9X3C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_ihQFUQDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_XGYvI5BR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HW55sIsL, m);
}

void Heavy_WSTD_FLANGR::cBinop_fNb3mqrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iAmGgJol, m);
}

void Heavy_WSTD_FLANGR::cMsg_Kyuo9X3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ihQFUQDc_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_XGYvI5BR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_A4vZiEVn, m);
}

void Heavy_WSTD_FLANGR::cMsg_GZSjUMcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GD0EozYH_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_GD0EozYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rwOHAaIw_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_jLHluPGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C9yVPkr5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_1hP0G4AU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fGzU0tTn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2SdWrC4r, m);
}

void Heavy_WSTD_FLANGR::cBinop_rwOHAaIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_txUTh9pr, m);
}

void Heavy_WSTD_FLANGR::cMsg_C9yVPkr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1hP0G4AU_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_fGzU0tTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SrdXwIA8, m);
}

void Heavy_WSTD_FLANGR::cBinop_43tkrBVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hC6AfDOA_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_hC6AfDOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_BGwFbpAD_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_7Qaguopv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9LIZYllN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_QJKtEzVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aZKS6in8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_BGwFbpAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fQRf55kY_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_fQRf55kY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GY6sQggc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3bGJwZzC_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_3bGJwZzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6djRzgfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_GY6sQggc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LU7Hjjia_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_LU7Hjjia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_J4aKoY35_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_6djRzgfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sa8q1mt4_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_sa8q1mt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_q3aDpUnb_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_J4aKoY35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_7Qaguopv_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_q3aDpUnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_QJKtEzVc_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_pPkWi7yG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LZfUXCOe_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_LZfUXCOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QXoE3hZB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_mDhelgeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_H9YTiKr9_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_H9YTiKr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JOtchA5m_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_C68n1UrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C68n1UrN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qno1IsWU, 0, m, &cDelay_Qno1IsWU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C68n1UrN, 0, m, &cDelay_C68n1UrN_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_s2VzStzY, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_Qno1IsWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Qno1IsWU, m);
  cMsg_jwac3JHU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_UsEpLwW0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_KWcJLhtl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_WmAvsNj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gUa9Onxw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_DxHcBV3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rcLjZQO9_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C68n1UrN, 2, m, &cDelay_C68n1UrN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8PViKq4_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_gUa9Onxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_DxHcBV3A, 0, m, &hTable_DxHcBV3A_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_JOtchA5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_WmAvsNj9_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_jwac3JHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_DxHcBV3A, 0, m, &hTable_DxHcBV3A_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_P8PViKq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C68n1UrN, 0, m, &cDelay_C68n1UrN_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_rcLjZQO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qno1IsWU, 2, m, &cDelay_Qno1IsWU_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_KWcJLhtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_s2VzStzY, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_Vv9i4P2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E4XverDM_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_E4XverDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Y5aTRNVt_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_BNs4tcAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BNs4tcAQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zjot6TCj, 0, m, &cDelay_zjot6TCj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BNs4tcAQ, 0, m, &cDelay_BNs4tcAQ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_L5lJraop, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_zjot6TCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zjot6TCj, m);
  cMsg_efX8Lsl8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_IKCeuUUC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_sT4WACbA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_t5QqMGh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_08dhQdUd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_jgmZW2QT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rF1rMK0E_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BNs4tcAQ, 2, m, &cDelay_BNs4tcAQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jJEHxudk_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_08dhQdUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_jgmZW2QT, 0, m, &hTable_jgmZW2QT_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Y5aTRNVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_t5QqMGh1_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_efX8Lsl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_jgmZW2QT, 0, m, &hTable_jgmZW2QT_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_jJEHxudk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BNs4tcAQ, 0, m, &cDelay_BNs4tcAQ_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_rF1rMK0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_zjot6TCj, 2, m, &cDelay_zjot6TCj_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_sT4WACbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_L5lJraop, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_u29N0OR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vfo7heMT, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vfo7heMT_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ptXKIqQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SQRoRnGJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_SQRoRnGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qVDdcArU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Vfo7heMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_FEPHMQlC_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_QXnU2srR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vfo7heMT, HV_BINOP_MULTIPLY, 1, m, &cBinop_Vfo7heMT_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_qVDdcArU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QXnU2srR_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_FEPHMQlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BljsAPWq_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_BljsAPWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mA4hRJqQ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_c3O92MqY, m);
}

void Heavy_WSTD_FLANGR::cBinop_mA4hRJqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7ykZFzU5, m);
}

void Heavy_WSTD_FLANGR::cVar_r0W7JjFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pDmR3hJ9, HV_BINOP_MULTIPLY, 0, m, &cBinop_pDmR3hJ9_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_74BrfDHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bkzV28xG_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_bkzV28xG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lqe3NFlZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_pDmR3hJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Ubhv3PT5_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Oa7dkHCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pDmR3hJ9, HV_BINOP_MULTIPLY, 1, m, &cBinop_pDmR3hJ9_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Lqe3NFlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Oa7dkHCg_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Ubhv3PT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9o5mtfH4_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9o5mtfH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0chZhu8p_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WQfHMqKZ, m);
}

void Heavy_WSTD_FLANGR::cBinop_0chZhu8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HfM7bbem, m);
}

void Heavy_WSTD_FLANGR::cMsg_QXoE3hZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gDU5lh0X, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_z79UFX9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_5d5GyiQ5_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_CHALRIh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_z79UFX9U_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_71fTv7yX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ak42yIeS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_nwQjNUqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QZSfGBqU_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_QZSfGBqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uQ5gO8fE, HV_BINOP_MULTIPLY, 1, m, &cBinop_uQ5gO8fE_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ak42yIeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_nwQjNUqH_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_uQ5gO8fE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JO6SiMH4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_5d5GyiQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uQ5gO8fE, HV_BINOP_MULTIPLY, 0, m, &cBinop_uQ5gO8fE_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_JO6SiMH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3KtmwMir, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_y755c3Ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_91b1uA4V_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_91b1uA4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_71fTv7yX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CHALRIh3_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_hgcc3HVv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CoNdFLTA, 0, m, &cSlice_CoNdFLTA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vDEeysWL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_CoNdFLTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_43I3CTvg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_43I3CTvg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_q0sab865_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_43I3CTvg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_43I3CTvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FHwzAZ05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_vDEeysWL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TKsyo9Oz, 0, m, &cSlice_TKsyo9Oz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FvKZ6yKq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_TKsyo9Oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6WQLZnnR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6WQLZnnR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_nO6GJWCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6WQLZnnR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_6WQLZnnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o97Be0Rd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_FvKZ6yKq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2QJuA9Q1, 0, m, &cSlice_2QJuA9Q1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pcZgrDga_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_2QJuA9Q1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IJ564GkU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IJ564GkU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_fQ7Rkf82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IJ564GkU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_IJ564GkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5rgCVfVK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_pcZgrDga_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YKIfFD3E, 0, m, &cSlice_YKIfFD3E_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_YKIfFD3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ikSRXXaG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ikSRXXaG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_WBpbeomY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ikSRXXaG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_ikSRXXaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_utcDAiZQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_9LIZYllN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cOXAjTOE, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_aZKS6in8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uKxGOAtF, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_qEDjJen2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hgcc3HVv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_pJVKp9yA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hgcc3HVv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_vYHG4Y6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hgcc3HVv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_BsgwgDl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hgcc3HVv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_2bvYIa42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q01Ehfur, 0, m, &cVar_Q01Ehfur_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_7Mp8wC4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OaXHNXaY, 0, m, &cVar_OaXHNXaY_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_2YBtzn09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MqpXQRtx, 0, m, &cVar_MqpXQRtx_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_5rgCVfVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_wxWmDgnU_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_o97Be0Rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_y755c3Ar_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_fJULiNYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ptXKIqQM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_u29N0OR8, 0, m, &cVar_u29N0OR8_sendMessage);
  cMsg_74BrfDHL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_r0W7JjFz, 0, m, &cVar_r0W7JjFz_sendMessage);
  cMsg_mDhelgeR_sendMessage(_c, 0, m);
  cMsg_Vv9i4P2L_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_q0sab865, 0, m, &cVar_q0sab865_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nO6GJWCw, 0, m, &cVar_nO6GJWCw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fQ7Rkf82, 0, m, &cVar_fQ7Rkf82_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WBpbeomY, 0, m, &cVar_WBpbeomY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2E4VzRYP, 0, m, &cVar_2E4VzRYP_sendMessage);
  cMsg_MbDV0M41_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jLHluPGR, 0, m, &cVar_jLHluPGR_sendMessage);
  cMsg_GZSjUMcu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_utcDAiZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_43tkrBVs_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_FHwzAZ05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pPkWi7yG_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_gdVpCjCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bwOctKai, 0, m, &cVar_bwOctKai_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_3mwyyNmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_2bvYIa42_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_UU9Ii3jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_2YBtzn09_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_iP7R4oiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_7Mp8wC4p_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_uKxGOAtF, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_hKlaHhOo, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_gDU5lh0X, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_c3O92MqY, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_7ykZFzU5, VOf(Bf3));
    __hv_rpole_f(&sRPole_lWDkJ9rI, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_WQfHMqKZ, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_HfM7bbem, VOf(Bf4));
    __hv_rpole_f(&sRPole_cala4zrT, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_BsmTXRg6, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_iAmGgJol, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_A4vZiEVn, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_HW55sIsL, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_6ZF0yv4n, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_Bx2t6pAh, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_cOXAjTOE, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_Fy3PzIjv, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_txUTh9pr, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_SrdXwIA8, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_2SdWrC4r, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_oEAgrLHI, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_YJGbDV5q, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_3KtmwMir, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_s2VzStzY, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_L5lJraop, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
