/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSystem.h"
#include "HvControlVar.h"
#include "HvControlSlice.h"
#include "HvTable.h"
#include "HvSignalPhasor.h"
#include "HvSignalVar.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvSignalRPole.h"
#include "HvControlCast.h"
#include "HvControlDelay.h"
#include "HvMath.h"
#include "HvSignalDel1.h"
#include "HvSignalTabread.h"
#include "HvSignalTabwrite.h"
#include "HvControlBinop.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_OaXHNXaY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bwOctKai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MqpXQRtx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Q01Ehfur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wxWmDgnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ztAFe2x9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MbDV0M41_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Q08GptsW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2E4VzRYP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ihQFUQDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fNb3mqrd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kyuo9X3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XGYvI5BR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GZSjUMcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GD0EozYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jLHluPGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1hP0G4AU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rwOHAaIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C9yVPkr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fGzU0tTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_43tkrBVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hC6AfDOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7Qaguopv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QJKtEzVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BGwFbpAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fQRf55kY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3bGJwZzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GY6sQggc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LU7Hjjia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6djRzgfK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sa8q1mt4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J4aKoY35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q3aDpUnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pPkWi7yG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LZfUXCOe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mDhelgeR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_H9YTiKr9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_C68n1UrN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Qno1IsWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UsEpLwW0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_WmAvsNj9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_DxHcBV3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gUa9Onxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JOtchA5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jwac3JHU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P8PViKq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rcLjZQO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KWcJLhtl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vv9i4P2L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_E4XverDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BNs4tcAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zjot6TCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IKCeuUUC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_t5QqMGh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_jgmZW2QT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_08dhQdUd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y5aTRNVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_efX8Lsl8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jJEHxudk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rF1rMK0E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sT4WACbA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_u29N0OR8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ptXKIqQM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SQRoRnGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vfo7heMT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QXnU2srR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qVDdcArU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FEPHMQlC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BljsAPWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mA4hRJqQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_r0W7JjFz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_74BrfDHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bkzV28xG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pDmR3hJ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oa7dkHCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lqe3NFlZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ubhv3PT5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9o5mtfH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0chZhu8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QXoE3hZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_z79UFX9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CHALRIh3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_71fTv7yX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nwQjNUqH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QZSfGBqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ak42yIeS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uQ5gO8fE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5d5GyiQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JO6SiMH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y755c3Ar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_91b1uA4V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hgcc3HVv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_CoNdFLTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_q0sab865_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_43I3CTvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vDEeysWL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_TKsyo9Oz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nO6GJWCw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6WQLZnnR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_FvKZ6yKq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_2QJuA9Q1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fQ7Rkf82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IJ564GkU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pcZgrDga_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_YKIfFD3E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WBpbeomY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ikSRXXaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9LIZYllN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aZKS6in8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qEDjJen2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pJVKp9yA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vYHG4Y6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BsgwgDl1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2bvYIa42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7Mp8wC4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2YBtzn09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5rgCVfVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o97Be0Rd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fJULiNYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_utcDAiZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FHwzAZ05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gdVpCjCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3mwyyNmg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UU9Ii3jo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iP7R4oiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_uKxGOAtF;
  SignalPhasor sPhasor_hKlaHhOo;
  SignalLine sLine_gDU5lh0X;
  SignalRPole sRPole_lWDkJ9rI;
  SignalRPole sRPole_cala4zrT;
  SignalTabhead sTabhead_BsmTXRg6;
  SignalTabread sTabread_6ZF0yv4n;
  SignalTabread sTabread_Bx2t6pAh;
  SignalLine sLine_cOXAjTOE;
  SignalTabhead sTabhead_Fy3PzIjv;
  SignalTabread sTabread_oEAgrLHI;
  SignalTabread sTabread_YJGbDV5q;
  SignalLine sLine_3KtmwMir;
  SignalTabwrite sTabwrite_s2VzStzY;
  SignalTabwrite sTabwrite_L5lJraop;
  ControlVar cVar_OaXHNXaY;
  ControlVar cVar_bwOctKai;
  ControlVar cVar_MqpXQRtx;
  ControlVar cVar_Q01Ehfur;
  ControlBinop cBinop_wxWmDgnU;
  ControlBinop cBinop_ztAFe2x9;
  ControlVar cVar_2E4VzRYP;
  ControlBinop cBinop_fNb3mqrd;
  ControlBinop cBinop_XGYvI5BR;
  SignalVarf sVarf_HW55sIsL;
  SignalVarf sVarf_iAmGgJol;
  SignalVarf sVarf_A4vZiEVn;
  ControlVar cVar_jLHluPGR;
  ControlBinop cBinop_rwOHAaIw;
  ControlBinop cBinop_fGzU0tTn;
  SignalVarf sVarf_2SdWrC4r;
  SignalVarf sVarf_txUTh9pr;
  SignalVarf sVarf_SrdXwIA8;
  ControlBinop cBinop_43tkrBVs;
  ControlBinop cBinop_hC6AfDOA;
  ControlBinop cBinop_BGwFbpAD;
  ControlBinop cBinop_fQRf55kY;
  ControlBinop cBinop_LU7Hjjia;
  ControlBinop cBinop_sa8q1mt4;
  ControlBinop cBinop_J4aKoY35;
  ControlBinop cBinop_q3aDpUnb;
  ControlBinop cBinop_pPkWi7yG;
  ControlBinop cBinop_LZfUXCOe;
  ControlDelay cDelay_C68n1UrN;
  ControlDelay cDelay_Qno1IsWU;
  ControlBinop cBinop_WmAvsNj9;
  HvTable hTable_DxHcBV3A;
  ControlBinop cBinop_JOtchA5m;
  ControlDelay cDelay_BNs4tcAQ;
  ControlDelay cDelay_zjot6TCj;
  ControlBinop cBinop_t5QqMGh1;
  HvTable hTable_jgmZW2QT;
  ControlBinop cBinop_Y5aTRNVt;
  ControlVar cVar_u29N0OR8;
  ControlBinop cBinop_Vfo7heMT;
  ControlBinop cBinop_QXnU2srR;
  SignalVarf sVarf_7ykZFzU5;
  ControlBinop cBinop_FEPHMQlC;
  ControlBinop cBinop_BljsAPWq;
  ControlBinop cBinop_mA4hRJqQ;
  SignalVarf sVarf_c3O92MqY;
  ControlVar cVar_r0W7JjFz;
  ControlBinop cBinop_pDmR3hJ9;
  ControlBinop cBinop_Oa7dkHCg;
  SignalVarf sVarf_HfM7bbem;
  ControlBinop cBinop_Ubhv3PT5;
  ControlBinop cBinop_9o5mtfH4;
  ControlBinop cBinop_0chZhu8p;
  SignalVarf sVarf_WQfHMqKZ;
  ControlBinop cBinop_nwQjNUqH;
  ControlBinop cBinop_QZSfGBqU;
  ControlBinop cBinop_ak42yIeS;
  ControlBinop cBinop_uQ5gO8fE;
  ControlBinop cBinop_5d5GyiQ5;
  ControlBinop cBinop_y755c3Ar;
  ControlBinop cBinop_91b1uA4V;
  ControlSlice cSlice_CoNdFLTA;
  ControlVar cVar_q0sab865;
  ControlSlice cSlice_TKsyo9Oz;
  ControlVar cVar_nO6GJWCw;
  ControlSlice cSlice_2QJuA9Q1;
  ControlVar cVar_fQ7Rkf82;
  ControlSlice cSlice_YKIfFD3E;
  ControlVar cVar_WBpbeomY;
  ControlBinop cBinop_2bvYIa42;
  ControlBinop cBinop_7Mp8wC4p;
  ControlBinop cBinop_2YBtzn09;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
